pub struct Error(/* private fields */);Implementations
Sourceimpl Error
impl Error
Sourcepub const CHANNEL_OVERFLOW: Error
pub const CHANNEL_OVERFLOW: Error
Set to true when appending a ViewTreeSnapshot in WatchResponse.updates
would exceed the limit of the FIDL channel. That snapshot is dropped, along with
older snapshots.
Sourcepub const BUFFER_OVERFLOW: Error
pub const BUFFER_OVERFLOW: Error
Set to true when appending a ViewTreeSnapshot in WatchResponse.updates
would exceed BUFFER_SIZE. That snapshot is dropped, along with older snapshots.
Sourcepub const VIEWS_OVERFLOW: Error
pub const VIEWS_OVERFLOW: Error
Set to true when the size of views in a ViewTreeSnapshot exceeds
MAX_VIEW_COUNT. We represent this situation in the ViewTreeSnapshot with an
unset views field.
Sourceimpl Error
impl Error
Sourcepub const fn bits(&self) -> u32
pub const fn bits(&self) -> u32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u32) -> Option<Error>
pub const fn from_bits(bits: u32) -> Option<Error>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u32) -> Error
pub const fn from_bits_truncate(bits: u32) -> Error
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u32) -> Error
pub const fn from_bits_retain(bits: u32) -> Error
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Error>
pub fn from_name(name: &str) -> Option<Error>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Error) -> bool
pub const fn intersects(&self, other: Error) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: Error) -> bool
pub const fn contains(&self, other: Error) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn remove(&mut self, other: Error)
pub fn remove(&mut self, other: Error)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Error)
pub fn toggle(&mut self, other: Error)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: Error, value: bool)
pub fn set(&mut self, other: Error, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Error) -> Error
pub const fn intersection(self, other: Error) -> Error
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(self, other: Error) -> Error
pub const fn union(self, other: Error) -> Error
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(self, other: Error) -> Error
pub const fn difference(self, other: Error) -> Error
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Error) -> Error
pub const fn symmetric_difference(self, other: Error) -> Error
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> Error
pub const fn complement(self) -> Error
The bitwise negation (!) of the bits in self, truncating the result.
Sourceimpl Error
impl Error
Sourcepub const fn iter(&self) -> Iter<Error>
pub const fn iter(&self) -> Iter<Error>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<Error>
pub const fn iter_names(&self) -> IterNames<Error>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.
Sourceimpl Error
impl Error
pub fn from_bits_allow_unknown(bits: u32) -> Error
pub fn has_unknown_bits(&self) -> bool
pub fn get_unknown_bits(&self) -> u32